==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIoChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PodIoChaosListFluent<A extends PodIoChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,PodIoChaos item);
    public A setToItems(int index,PodIoChaos item);
    public A addToItems(PodIoChaos... items);
    public A addAllToItems(Collection<PodIoChaos> items);
    public A removeFromItems(PodIoChaos... items);
    public A removeAllFromItems(Collection<PodIoChaos> items);
    public A removeMatchingFromItems(Predicate<PodIoChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodIoChaos> getItems();
    public List<PodIoChaos> buildItems();
    public PodIoChaos buildItem(int index);
    public PodIoChaos buildFirstItem();
    public PodIoChaos buildLastItem();
    public PodIoChaos buildMatchingItem(Predicate<PodIoChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PodIoChaosBuilder> predicate);
    public A withItems(List<PodIoChaos> items);
    public A withItems(PodIoChaos... items);
    public Boolean hasItems();
    public PodIoChaosListFluent.ItemsNested<A> addNewItem();
    public PodIoChaosListFluent.ItemsNested<A> addNewItemLike(PodIoChaos item);
    public PodIoChaosListFluent.ItemsNested<A> setNewItemLike(int index,PodIoChaos item);
    public PodIoChaosListFluent.ItemsNested<A> editItem(int index);
    public PodIoChaosListFluent.ItemsNested<A> editFirstItem();
    public PodIoChaosListFluent.ItemsNested<A> editLastItem();
    public PodIoChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodIoChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodIoChaosFluent<PodIoChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIoChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PodIoChaosListFluent<A extends PodIoChaosListFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,PodIoChaos item);
    public A setToItems(int index,PodIoChaos item);
    public A addToItems(PodIoChaos... items);
    public A addAllToItems(Collection<PodIoChaos> items);
    public A removeFromItems(PodIoChaos... items);
    public A removeAllFromItems(Collection<PodIoChaos> items);
    public A removeMatchingFromItems(Predicate<PodIoChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodIoChaos> getItems();
    public List<PodIoChaos> buildItems();
    public PodIoChaos buildItem(int index);
    public PodIoChaos buildFirstItem();
    public PodIoChaos buildLastItem();
    public PodIoChaos buildMatchingItem(Predicate<PodIoChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PodIoChaosBuilder> predicate);
    public A withItems(List<PodIoChaos> items);
    public A withItems(PodIoChaos... items);
    public Boolean hasItems();
    public io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<A> addNewItem();
    public io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<A> addNewItemLike(PodIoChaos item);
    public io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<A> setNewItemLike(int index,PodIoChaos item);
    public io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<A> editItem(int index);
    public io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<A> editFirstItem();
    public io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<A> editLastItem();
    public io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodIoChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodIoChaosFluent<io.fabric8.chaosmesh.v1alpha1.PodIoChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
